# Rust API client for spoonacular

The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.

Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.

For more information, please visit [https://spoonacular.com/contact](https://spoonacular.com/contact)

## Overview

This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [openapi-spec](https://openapis.org) from a remote server, you can easily generate an API client.

- API version: 1.1
- Package version: 1.1.1
- Build package: `org.openapitools.codegen.languages.RustClientCodegen`

## Installation

Put the package under your project folder in a directory named `spoonacular` and add the following to `Cargo.toml` under `[dependencies]`:

```
spoonacular = { path = "./spoonacular" }
```

## Documentation for API Endpoints

All URIs are relative to *https://api.spoonacular.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**analyze_recipe**](docs/DefaultApi.md#analyze_recipe) | **POST** /recipes/analyze | Analyze Recipe
*DefaultApi* | [**create_recipe_card_get**](docs/DefaultApi.md#create_recipe_card_get) | **GET** /recipes/{id}/card | Create Recipe Card
*DefaultApi* | [**search_restaurants**](docs/DefaultApi.md#search_restaurants) | **GET** /food/restaurants/search | Search Restaurants
*IngredientsApi* | [**autocomplete_ingredient_search**](docs/IngredientsApi.md#autocomplete_ingredient_search) | **GET** /food/ingredients/autocomplete | Autocomplete Ingredient Search
*IngredientsApi* | [**compute_ingredient_amount**](docs/IngredientsApi.md#compute_ingredient_amount) | **GET** /food/ingredients/{id}/amount | Compute Ingredient Amount
*IngredientsApi* | [**get_ingredient_information**](docs/IngredientsApi.md#get_ingredient_information) | **GET** /food/ingredients/{id}/information | Get Ingredient Information
*IngredientsApi* | [**get_ingredient_substitutes**](docs/IngredientsApi.md#get_ingredient_substitutes) | **GET** /food/ingredients/substitutes | Get Ingredient Substitutes
*IngredientsApi* | [**get_ingredient_substitutes_by_id**](docs/IngredientsApi.md#get_ingredient_substitutes_by_id) | **GET** /food/ingredients/{id}/substitutes | Get Ingredient Substitutes by ID
*IngredientsApi* | [**ingredient_search**](docs/IngredientsApi.md#ingredient_search) | **GET** /food/ingredients/search | Ingredient Search
*IngredientsApi* | [**ingredients_by_id_image**](docs/IngredientsApi.md#ingredients_by_id_image) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*IngredientsApi* | [**map_ingredients_to_grocery_products**](docs/IngredientsApi.md#map_ingredients_to_grocery_products) | **POST** /food/ingredients/map | Map Ingredients to Grocery Products
*IngredientsApi* | [**visualize_ingredients**](docs/IngredientsApi.md#visualize_ingredients) | **POST** /recipes/visualizeIngredients | Ingredients Widget
*MealPlanningApi* | [**add_meal_plan_template**](docs/MealPlanningApi.md#add_meal_plan_template) | **POST** /mealplanner/{username}/templates | Add Meal Plan Template
*MealPlanningApi* | [**add_to_meal_plan**](docs/MealPlanningApi.md#add_to_meal_plan) | **POST** /mealplanner/{username}/items | Add to Meal Plan
*MealPlanningApi* | [**add_to_shopping_list**](docs/MealPlanningApi.md#add_to_shopping_list) | **POST** /mealplanner/{username}/shopping-list/items | Add to Shopping List
*MealPlanningApi* | [**clear_meal_plan_day**](docs/MealPlanningApi.md#clear_meal_plan_day) | **DELETE** /mealplanner/{username}/day/{date} | Clear Meal Plan Day
*MealPlanningApi* | [**connect_user**](docs/MealPlanningApi.md#connect_user) | **POST** /users/connect | Connect User
*MealPlanningApi* | [**delete_from_meal_plan**](docs/MealPlanningApi.md#delete_from_meal_plan) | **DELETE** /mealplanner/{username}/items/{id} | Delete from Meal Plan
*MealPlanningApi* | [**delete_from_shopping_list**](docs/MealPlanningApi.md#delete_from_shopping_list) | **DELETE** /mealplanner/{username}/shopping-list/items/{id} | Delete from Shopping List
*MealPlanningApi* | [**delete_meal_plan_template**](docs/MealPlanningApi.md#delete_meal_plan_template) | **DELETE** /mealplanner/{username}/templates/{id} | Delete Meal Plan Template
*MealPlanningApi* | [**generate_meal_plan**](docs/MealPlanningApi.md#generate_meal_plan) | **GET** /mealplanner/generate | Generate Meal Plan
*MealPlanningApi* | [**generate_shopping_list**](docs/MealPlanningApi.md#generate_shopping_list) | **POST** /mealplanner/{username}/shopping-list/{start-date}/{end-date} | Generate Shopping List
*MealPlanningApi* | [**get_meal_plan_template**](docs/MealPlanningApi.md#get_meal_plan_template) | **GET** /mealplanner/{username}/templates/{id} | Get Meal Plan Template
*MealPlanningApi* | [**get_meal_plan_templates**](docs/MealPlanningApi.md#get_meal_plan_templates) | **GET** /mealplanner/{username}/templates | Get Meal Plan Templates
*MealPlanningApi* | [**get_meal_plan_week**](docs/MealPlanningApi.md#get_meal_plan_week) | **GET** /mealplanner/{username}/week/{start-date} | Get Meal Plan Week
*MealPlanningApi* | [**get_shopping_list**](docs/MealPlanningApi.md#get_shopping_list) | **GET** /mealplanner/{username}/shopping-list | Get Shopping List
*MenuItemsApi* | [**autocomplete_menu_item_search**](docs/MenuItemsApi.md#autocomplete_menu_item_search) | **GET** /food/menuItems/suggest | Autocomplete Menu Item Search
*MenuItemsApi* | [**get_menu_item_information**](docs/MenuItemsApi.md#get_menu_item_information) | **GET** /food/menuItems/{id} | Get Menu Item Information
*MenuItemsApi* | [**menu_item_nutrition_by_id_image**](docs/MenuItemsApi.md#menu_item_nutrition_by_id_image) | **GET** /food/menuItems/{id}/nutritionWidget.png | Menu Item Nutrition by ID Image
*MenuItemsApi* | [**menu_item_nutrition_label_image**](docs/MenuItemsApi.md#menu_item_nutrition_label_image) | **GET** /food/menuItems/{id}/nutritionLabel.png | Menu Item Nutrition Label Image
*MenuItemsApi* | [**menu_item_nutrition_label_widget**](docs/MenuItemsApi.md#menu_item_nutrition_label_widget) | **GET** /food/menuItems/{id}/nutritionLabel | Menu Item Nutrition Label Widget
*MenuItemsApi* | [**search_menu_items**](docs/MenuItemsApi.md#search_menu_items) | **GET** /food/menuItems/search | Search Menu Items
*MenuItemsApi* | [**visualize_menu_item_nutrition_by_id**](docs/MenuItemsApi.md#visualize_menu_item_nutrition_by_id) | **GET** /food/menuItems/{id}/nutritionWidget | Menu Item Nutrition by ID Widget
*MiscApi* | [**detect_food_in_text**](docs/MiscApi.md#detect_food_in_text) | **POST** /food/detect | Detect Food in Text
*MiscApi* | [**get_a_random_food_joke**](docs/MiscApi.md#get_a_random_food_joke) | **GET** /food/jokes/random | Random Food Joke
*MiscApi* | [**get_conversation_suggests**](docs/MiscApi.md#get_conversation_suggests) | **GET** /food/converse/suggest | Conversation Suggests
*MiscApi* | [**get_random_food_trivia**](docs/MiscApi.md#get_random_food_trivia) | **GET** /food/trivia/random | Random Food Trivia
*MiscApi* | [**image_analysis_by_url**](docs/MiscApi.md#image_analysis_by_url) | **GET** /food/images/analyze | Image Analysis by URL
*MiscApi* | [**image_classification_by_url**](docs/MiscApi.md#image_classification_by_url) | **GET** /food/images/classify | Image Classification by URL
*MiscApi* | [**search_all_food**](docs/MiscApi.md#search_all_food) | **GET** /food/search | Search All Food
*MiscApi* | [**search_custom_foods**](docs/MiscApi.md#search_custom_foods) | **GET** /food/customFoods/search | Search Custom Foods
*MiscApi* | [**search_food_videos**](docs/MiscApi.md#search_food_videos) | **GET** /food/videos/search | Search Food Videos
*MiscApi* | [**search_site_content**](docs/MiscApi.md#search_site_content) | **GET** /food/site/search | Search Site Content
*MiscApi* | [**talk_to_chatbot**](docs/MiscApi.md#talk_to_chatbot) | **GET** /food/converse | Talk to Chatbot
*ProductsApi* | [**autocomplete_product_search**](docs/ProductsApi.md#autocomplete_product_search) | **GET** /food/products/suggest | Autocomplete Product Search
*ProductsApi* | [**classify_grocery_product**](docs/ProductsApi.md#classify_grocery_product) | **POST** /food/products/classify | Classify Grocery Product
*ProductsApi* | [**classify_grocery_product_bulk**](docs/ProductsApi.md#classify_grocery_product_bulk) | **POST** /food/products/classifyBatch | Classify Grocery Product Bulk
*ProductsApi* | [**get_comparable_products**](docs/ProductsApi.md#get_comparable_products) | **GET** /food/products/upc/{upc}/comparable | Get Comparable Products
*ProductsApi* | [**get_product_information**](docs/ProductsApi.md#get_product_information) | **GET** /food/products/{id} | Get Product Information
*ProductsApi* | [**product_nutrition_by_id_image**](docs/ProductsApi.md#product_nutrition_by_id_image) | **GET** /food/products/{id}/nutritionWidget.png | Product Nutrition by ID Image
*ProductsApi* | [**product_nutrition_label_image**](docs/ProductsApi.md#product_nutrition_label_image) | **GET** /food/products/{id}/nutritionLabel.png | Product Nutrition Label Image
*ProductsApi* | [**product_nutrition_label_widget**](docs/ProductsApi.md#product_nutrition_label_widget) | **GET** /food/products/{id}/nutritionLabel | Product Nutrition Label Widget
*ProductsApi* | [**search_grocery_products**](docs/ProductsApi.md#search_grocery_products) | **GET** /food/products/search | Search Grocery Products
*ProductsApi* | [**search_grocery_products_by_upc**](docs/ProductsApi.md#search_grocery_products_by_upc) | **GET** /food/products/upc/{upc} | Search Grocery Products by UPC
*ProductsApi* | [**visualize_product_nutrition_by_id**](docs/ProductsApi.md#visualize_product_nutrition_by_id) | **GET** /food/products/{id}/nutritionWidget | Product Nutrition by ID Widget
*RecipesApi* | [**analyze_a_recipe_search_query**](docs/RecipesApi.md#analyze_a_recipe_search_query) | **GET** /recipes/queries/analyze | Analyze a Recipe Search Query
*RecipesApi* | [**analyze_recipe_instructions**](docs/RecipesApi.md#analyze_recipe_instructions) | **POST** /recipes/analyzeInstructions | Analyze Recipe Instructions
*RecipesApi* | [**autocomplete_recipe_search**](docs/RecipesApi.md#autocomplete_recipe_search) | **GET** /recipes/autocomplete | Autocomplete Recipe Search
*RecipesApi* | [**classify_cuisine**](docs/RecipesApi.md#classify_cuisine) | **POST** /recipes/cuisine | Classify Cuisine
*RecipesApi* | [**compute_glycemic_load**](docs/RecipesApi.md#compute_glycemic_load) | **POST** /food/ingredients/glycemicLoad | Compute Glycemic Load
*RecipesApi* | [**convert_amounts**](docs/RecipesApi.md#convert_amounts) | **GET** /recipes/convert | Convert Amounts
*RecipesApi* | [**create_recipe_card**](docs/RecipesApi.md#create_recipe_card) | **POST** /recipes/visualizeRecipe | Create Recipe Card
*RecipesApi* | [**equipment_by_id_image**](docs/RecipesApi.md#equipment_by_id_image) | **GET** /recipes/{id}/equipmentWidget.png | Equipment by ID Image
*RecipesApi* | [**extract_recipe_from_website**](docs/RecipesApi.md#extract_recipe_from_website) | **GET** /recipes/extract | Extract Recipe from Website
*RecipesApi* | [**get_analyzed_recipe_instructions**](docs/RecipesApi.md#get_analyzed_recipe_instructions) | **GET** /recipes/{id}/analyzedInstructions | Get Analyzed Recipe Instructions
*RecipesApi* | [**get_random_recipes**](docs/RecipesApi.md#get_random_recipes) | **GET** /recipes/random | Get Random Recipes
*RecipesApi* | [**get_recipe_equipment_by_id**](docs/RecipesApi.md#get_recipe_equipment_by_id) | **GET** /recipes/{id}/equipmentWidget.json | Equipment by ID
*RecipesApi* | [**get_recipe_information**](docs/RecipesApi.md#get_recipe_information) | **GET** /recipes/{id}/information | Get Recipe Information
*RecipesApi* | [**get_recipe_information_bulk**](docs/RecipesApi.md#get_recipe_information_bulk) | **GET** /recipes/informationBulk | Get Recipe Information Bulk
*RecipesApi* | [**get_recipe_ingredients_by_id**](docs/RecipesApi.md#get_recipe_ingredients_by_id) | **GET** /recipes/{id}/ingredientWidget.json | Ingredients by ID
*RecipesApi* | [**get_recipe_nutrition_widget_by_id**](docs/RecipesApi.md#get_recipe_nutrition_widget_by_id) | **GET** /recipes/{id}/nutritionWidget.json | Nutrition by ID
*RecipesApi* | [**get_recipe_price_breakdown_by_id**](docs/RecipesApi.md#get_recipe_price_breakdown_by_id) | **GET** /recipes/{id}/priceBreakdownWidget.json | Price Breakdown by ID
*RecipesApi* | [**get_recipe_taste_by_id**](docs/RecipesApi.md#get_recipe_taste_by_id) | **GET** /recipes/{id}/tasteWidget.json | Taste by ID
*RecipesApi* | [**get_similar_recipes**](docs/RecipesApi.md#get_similar_recipes) | **GET** /recipes/{id}/similar | Get Similar Recipes
*RecipesApi* | [**guess_nutrition_by_dish_name**](docs/RecipesApi.md#guess_nutrition_by_dish_name) | **GET** /recipes/guessNutrition | Guess Nutrition by Dish Name
*RecipesApi* | [**ingredients_by_id_image**](docs/RecipesApi.md#ingredients_by_id_image) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*RecipesApi* | [**parse_ingredients**](docs/RecipesApi.md#parse_ingredients) | **POST** /recipes/parseIngredients | Parse Ingredients
*RecipesApi* | [**price_breakdown_by_id_image**](docs/RecipesApi.md#price_breakdown_by_id_image) | **GET** /recipes/{id}/priceBreakdownWidget.png | Price Breakdown by ID Image
*RecipesApi* | [**quick_answer**](docs/RecipesApi.md#quick_answer) | **GET** /recipes/quickAnswer | Quick Answer
*RecipesApi* | [**recipe_nutrition_by_id_image**](docs/RecipesApi.md#recipe_nutrition_by_id_image) | **GET** /recipes/{id}/nutritionWidget.png | Recipe Nutrition by ID Image
*RecipesApi* | [**recipe_nutrition_label_image**](docs/RecipesApi.md#recipe_nutrition_label_image) | **GET** /recipes/{id}/nutritionLabel.png | Recipe Nutrition Label Image
*RecipesApi* | [**recipe_nutrition_label_widget**](docs/RecipesApi.md#recipe_nutrition_label_widget) | **GET** /recipes/{id}/nutritionLabel | Recipe Nutrition Label Widget
*RecipesApi* | [**recipe_taste_by_id_image**](docs/RecipesApi.md#recipe_taste_by_id_image) | **GET** /recipes/{id}/tasteWidget.png | Recipe Taste by ID Image
*RecipesApi* | [**search_recipes**](docs/RecipesApi.md#search_recipes) | **GET** /recipes/complexSearch | Search Recipes
*RecipesApi* | [**search_recipes_by_ingredients**](docs/RecipesApi.md#search_recipes_by_ingredients) | **GET** /recipes/findByIngredients | Search Recipes by Ingredients
*RecipesApi* | [**search_recipes_by_nutrients**](docs/RecipesApi.md#search_recipes_by_nutrients) | **GET** /recipes/findByNutrients | Search Recipes by Nutrients
*RecipesApi* | [**summarize_recipe**](docs/RecipesApi.md#summarize_recipe) | **GET** /recipes/{id}/summary | Summarize Recipe
*RecipesApi* | [**visualize_equipment**](docs/RecipesApi.md#visualize_equipment) | **POST** /recipes/visualizeEquipment | Equipment Widget
*RecipesApi* | [**visualize_price_breakdown**](docs/RecipesApi.md#visualize_price_breakdown) | **POST** /recipes/visualizePriceEstimator | Price Breakdown Widget
*RecipesApi* | [**visualize_recipe_equipment_by_id**](docs/RecipesApi.md#visualize_recipe_equipment_by_id) | **GET** /recipes/{id}/equipmentWidget | Equipment by ID Widget
*RecipesApi* | [**visualize_recipe_ingredients_by_id**](docs/RecipesApi.md#visualize_recipe_ingredients_by_id) | **GET** /recipes/{id}/ingredientWidget | Ingredients by ID Widget
*RecipesApi* | [**visualize_recipe_nutrition**](docs/RecipesApi.md#visualize_recipe_nutrition) | **POST** /recipes/visualizeNutrition | Recipe Nutrition Widget
*RecipesApi* | [**visualize_recipe_nutrition_by_id**](docs/RecipesApi.md#visualize_recipe_nutrition_by_id) | **GET** /recipes/{id}/nutritionWidget | Recipe Nutrition by ID Widget
*RecipesApi* | [**visualize_recipe_price_breakdown_by_id**](docs/RecipesApi.md#visualize_recipe_price_breakdown_by_id) | **GET** /recipes/{id}/priceBreakdownWidget | Price Breakdown by ID Widget
*RecipesApi* | [**visualize_recipe_taste**](docs/RecipesApi.md#visualize_recipe_taste) | **POST** /recipes/visualizeTaste | Recipe Taste Widget
*RecipesApi* | [**visualize_recipe_taste_by_id**](docs/RecipesApi.md#visualize_recipe_taste_by_id) | **GET** /recipes/{id}/tasteWidget | Recipe Taste by ID Widget
*WineApi* | [**get_dish_pairing_for_wine**](docs/WineApi.md#get_dish_pairing_for_wine) | **GET** /food/wine/dishes | Dish Pairing for Wine
*WineApi* | [**get_wine_description**](docs/WineApi.md#get_wine_description) | **GET** /food/wine/description | Wine Description
*WineApi* | [**get_wine_pairing**](docs/WineApi.md#get_wine_pairing) | **GET** /food/wine/pairing | Wine Pairing
*WineApi* | [**get_wine_recommendation**](docs/WineApi.md#get_wine_recommendation) | **GET** /food/wine/recommendation | Wine Recommendation


## Documentation For Models

 - [AddMealPlanTemplate200Response](docs/AddMealPlanTemplate200Response.md)
 - [AddMealPlanTemplate200ResponseItemsInner](docs/AddMealPlanTemplate200ResponseItemsInner.md)
 - [AddMealPlanTemplate200ResponseItemsInnerValue](docs/AddMealPlanTemplate200ResponseItemsInnerValue.md)
 - [AddToMealPlanRequest](docs/AddToMealPlanRequest.md)
 - [AddToMealPlanRequest1](docs/AddToMealPlanRequest1.md)
 - [AddToMealPlanRequest1Value](docs/AddToMealPlanRequest1Value.md)
 - [AddToMealPlanRequest1ValueIngredientsInner](docs/AddToMealPlanRequest1ValueIngredientsInner.md)
 - [AddToShoppingListRequest](docs/AddToShoppingListRequest.md)
 - [AnalyzeARecipeSearchQuery200Response](docs/AnalyzeARecipeSearchQuery200Response.md)
 - [AnalyzeARecipeSearchQuery200ResponseDishesInner](docs/AnalyzeARecipeSearchQuery200ResponseDishesInner.md)
 - [AnalyzeARecipeSearchQuery200ResponseIngredientsInner](docs/AnalyzeARecipeSearchQuery200ResponseIngredientsInner.md)
 - [AnalyzeRecipeInstructions200Response](docs/AnalyzeRecipeInstructions200Response.md)
 - [AnalyzeRecipeInstructions200ResponseIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseIngredientsInner.md)
 - [AnalyzeRecipeInstructions200ResponseParsedInstructionsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [AnalyzeRecipeRequest](docs/AnalyzeRecipeRequest.md)
 - [AnalyzeRecipeRequest1](docs/AnalyzeRecipeRequest1.md)
 - [AutocompleteIngredientSearch200ResponseInner](docs/AutocompleteIngredientSearch200ResponseInner.md)
 - [AutocompleteMenuItemSearch200Response](docs/AutocompleteMenuItemSearch200Response.md)
 - [AutocompleteProductSearch200Response](docs/AutocompleteProductSearch200Response.md)
 - [AutocompleteProductSearch200ResponseResultsInner](docs/AutocompleteProductSearch200ResponseResultsInner.md)
 - [AutocompleteRecipeSearch200ResponseInner](docs/AutocompleteRecipeSearch200ResponseInner.md)
 - [ClassifyCuisine200Response](docs/ClassifyCuisine200Response.md)
 - [ClassifyGroceryProduct200Response](docs/ClassifyGroceryProduct200Response.md)
 - [ClassifyGroceryProductBulk200ResponseInner](docs/ClassifyGroceryProductBulk200ResponseInner.md)
 - [ClassifyGroceryProductBulkRequestInner](docs/ClassifyGroceryProductBulkRequestInner.md)
 - [ClassifyGroceryProductRequest](docs/ClassifyGroceryProductRequest.md)
 - [ClearMealPlanDayRequest](docs/ClearMealPlanDayRequest.md)
 - [ComputeGlycemicLoad200Response](docs/ComputeGlycemicLoad200Response.md)
 - [ComputeGlycemicLoad200ResponseIngredientsInner](docs/ComputeGlycemicLoad200ResponseIngredientsInner.md)
 - [ComputeGlycemicLoadRequest](docs/ComputeGlycemicLoadRequest.md)
 - [ComputeIngredientAmount200Response](docs/ComputeIngredientAmount200Response.md)
 - [ConnectUser200Response](docs/ConnectUser200Response.md)
 - [ConnectUserRequest](docs/ConnectUserRequest.md)
 - [ConvertAmounts200Response](docs/ConvertAmounts200Response.md)
 - [CreateRecipeCard200Response](docs/CreateRecipeCard200Response.md)
 - [DeleteFromMealPlanRequest](docs/DeleteFromMealPlanRequest.md)
 - [DetectFoodInText200Response](docs/DetectFoodInText200Response.md)
 - [DetectFoodInText200ResponseAnnotationsInner](docs/DetectFoodInText200ResponseAnnotationsInner.md)
 - [GenerateMealPlan200Response](docs/GenerateMealPlan200Response.md)
 - [GenerateMealPlan200ResponseNutrients](docs/GenerateMealPlan200ResponseNutrients.md)
 - [GenerateShoppingList200Response](docs/GenerateShoppingList200Response.md)
 - [GenerateShoppingListRequest](docs/GenerateShoppingListRequest.md)
 - [GetARandomFoodJoke200Response](docs/GetARandomFoodJoke200Response.md)
 - [GetAnalyzedRecipeInstructions200Response](docs/GetAnalyzedRecipeInstructions200Response.md)
 - [GetAnalyzedRecipeInstructions200ResponseIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseIngredientsInner.md)
 - [GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [GetComparableProducts200Response](docs/GetComparableProducts200Response.md)
 - [GetComparableProducts200ResponseComparableProducts](docs/GetComparableProducts200ResponseComparableProducts.md)
 - [GetComparableProducts200ResponseComparableProductsProteinInner](docs/GetComparableProducts200ResponseComparableProductsProteinInner.md)
 - [GetConversationSuggests200Response](docs/GetConversationSuggests200Response.md)
 - [GetConversationSuggests200ResponseSuggests](docs/GetConversationSuggests200ResponseSuggests.md)
 - [GetConversationSuggests200ResponseSuggestsInner](docs/GetConversationSuggests200ResponseSuggestsInner.md)
 - [GetDishPairingForWine200Response](docs/GetDishPairingForWine200Response.md)
 - [GetIngredientInformation200Response](docs/GetIngredientInformation200Response.md)
 - [GetIngredientInformation200ResponseNutrition](docs/GetIngredientInformation200ResponseNutrition.md)
 - [GetIngredientSubstitutes200Response](docs/GetIngredientSubstitutes200Response.md)
 - [GetMealPlanTemplate200Response](docs/GetMealPlanTemplate200Response.md)
 - [GetMealPlanTemplate200ResponseDaysInner](docs/GetMealPlanTemplate200ResponseDaysInner.md)
 - [GetMealPlanTemplate200ResponseDaysInnerItemsInner](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInner.md)
 - [GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue.md)
 - [GetMealPlanTemplates200Response](docs/GetMealPlanTemplates200Response.md)
 - [GetMealPlanWeek200Response](docs/GetMealPlanWeek200Response.md)
 - [GetMealPlanWeek200ResponseDaysInner](docs/GetMealPlanWeek200ResponseDaysInner.md)
 - [GetMealPlanWeek200ResponseDaysInnerItemsInner](docs/GetMealPlanWeek200ResponseDaysInnerItemsInner.md)
 - [GetMealPlanWeek200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanWeek200ResponseDaysInnerItemsInnerValue.md)
 - [GetMealPlanWeek200ResponseDaysInnerNutritionSummary](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummary.md)
 - [GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner.md)
 - [GetMenuItemInformation200Response](docs/GetMenuItemInformation200Response.md)
 - [GetProductInformation200Response](docs/GetProductInformation200Response.md)
 - [GetProductInformation200ResponseIngredientsInner](docs/GetProductInformation200ResponseIngredientsInner.md)
 - [GetRandomFoodTrivia200Response](docs/GetRandomFoodTrivia200Response.md)
 - [GetRandomRecipes200Response](docs/GetRandomRecipes200Response.md)
 - [GetRandomRecipes200ResponseRecipesInner](docs/GetRandomRecipes200ResponseRecipesInner.md)
 - [GetRecipeEquipmentById200Response](docs/GetRecipeEquipmentById200Response.md)
 - [GetRecipeEquipmentById200ResponseEquipmentInner](docs/GetRecipeEquipmentById200ResponseEquipmentInner.md)
 - [GetRecipeInformation200Response](docs/GetRecipeInformation200Response.md)
 - [GetRecipeInformation200ResponseExtendedIngredientsInner](docs/GetRecipeInformation200ResponseExtendedIngredientsInner.md)
 - [GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures.md)
 - [GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric.md)
 - [GetRecipeInformation200ResponseWinePairing](docs/GetRecipeInformation200ResponseWinePairing.md)
 - [GetRecipeInformation200ResponseWinePairingProductMatchesInner](docs/GetRecipeInformation200ResponseWinePairingProductMatchesInner.md)
 - [GetRecipeInformationBulk200ResponseInner](docs/GetRecipeInformationBulk200ResponseInner.md)
 - [GetRecipeIngredientsById200Response](docs/GetRecipeIngredientsById200Response.md)
 - [GetRecipeIngredientsById200ResponseIngredientsInner](docs/GetRecipeIngredientsById200ResponseIngredientsInner.md)
 - [GetRecipeNutritionWidgetById200Response](docs/GetRecipeNutritionWidgetById200Response.md)
 - [GetRecipeNutritionWidgetById200ResponseBadInner](docs/GetRecipeNutritionWidgetById200ResponseBadInner.md)
 - [GetRecipeNutritionWidgetById200ResponseGoodInner](docs/GetRecipeNutritionWidgetById200ResponseGoodInner.md)
 - [GetRecipePriceBreakdownById200Response](docs/GetRecipePriceBreakdownById200Response.md)
 - [GetRecipePriceBreakdownById200ResponseIngredientsInner](docs/GetRecipePriceBreakdownById200ResponseIngredientsInner.md)
 - [GetRecipePriceBreakdownById200ResponseIngredientsInnerAmount](docs/GetRecipePriceBreakdownById200ResponseIngredientsInnerAmount.md)
 - [GetRecipePriceBreakdownById200ResponseIngredientsInnerAmountMetric](docs/GetRecipePriceBreakdownById200ResponseIngredientsInnerAmountMetric.md)
 - [GetRecipeTasteById200Response](docs/GetRecipeTasteById200Response.md)
 - [GetShoppingList200Response](docs/GetShoppingList200Response.md)
 - [GetShoppingList200ResponseAislesInner](docs/GetShoppingList200ResponseAislesInner.md)
 - [GetShoppingList200ResponseAislesInnerItemsInner](docs/GetShoppingList200ResponseAislesInnerItemsInner.md)
 - [GetShoppingList200ResponseAislesInnerItemsInnerMeasures](docs/GetShoppingList200ResponseAislesInnerItemsInnerMeasures.md)
 - [GetSimilarRecipes200ResponseInner](docs/GetSimilarRecipes200ResponseInner.md)
 - [GetWineDescription200Response](docs/GetWineDescription200Response.md)
 - [GetWinePairing200Response](docs/GetWinePairing200Response.md)
 - [GetWinePairing200ResponseProductMatchesInner](docs/GetWinePairing200ResponseProductMatchesInner.md)
 - [GetWineRecommendation200Response](docs/GetWineRecommendation200Response.md)
 - [GetWineRecommendation200ResponseRecommendedWinesInner](docs/GetWineRecommendation200ResponseRecommendedWinesInner.md)
 - [GuessNutritionByDishName200Response](docs/GuessNutritionByDishName200Response.md)
 - [GuessNutritionByDishName200ResponseCalories](docs/GuessNutritionByDishName200ResponseCalories.md)
 - [GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent](docs/GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent.md)
 - [ImageAnalysisByUrl200Response](docs/ImageAnalysisByUrl200Response.md)
 - [ImageAnalysisByUrl200ResponseCategory](docs/ImageAnalysisByUrl200ResponseCategory.md)
 - [ImageAnalysisByUrl200ResponseNutrition](docs/ImageAnalysisByUrl200ResponseNutrition.md)
 - [ImageAnalysisByUrl200ResponseNutritionCalories](docs/ImageAnalysisByUrl200ResponseNutritionCalories.md)
 - [ImageAnalysisByUrl200ResponseNutritionCaloriesConfidenceRange95Percent](docs/ImageAnalysisByUrl200ResponseNutritionCaloriesConfidenceRange95Percent.md)
 - [ImageAnalysisByUrl200ResponseRecipesInner](docs/ImageAnalysisByUrl200ResponseRecipesInner.md)
 - [ImageClassificationByUrl200Response](docs/ImageClassificationByUrl200Response.md)
 - [IngredientSearch200Response](docs/IngredientSearch200Response.md)
 - [IngredientSearch200ResponseResultsInner](docs/IngredientSearch200ResponseResultsInner.md)
 - [MapIngredientsToGroceryProducts200ResponseInner](docs/MapIngredientsToGroceryProducts200ResponseInner.md)
 - [MapIngredientsToGroceryProducts200ResponseInnerProductsInner](docs/MapIngredientsToGroceryProducts200ResponseInnerProductsInner.md)
 - [MapIngredientsToGroceryProductsRequest](docs/MapIngredientsToGroceryProductsRequest.md)
 - [ParseIngredients200ResponseInner](docs/ParseIngredients200ResponseInner.md)
 - [ParseIngredients200ResponseInnerEstimatedCost](docs/ParseIngredients200ResponseInnerEstimatedCost.md)
 - [ParseIngredients200ResponseInnerNutrition](docs/ParseIngredients200ResponseInnerNutrition.md)
 - [ParseIngredients200ResponseInnerNutritionCaloricBreakdown](docs/ParseIngredients200ResponseInnerNutritionCaloricBreakdown.md)
 - [ParseIngredients200ResponseInnerNutritionNutrientsInner](docs/ParseIngredients200ResponseInnerNutritionNutrientsInner.md)
 - [ParseIngredients200ResponseInnerNutritionPropertiesInner](docs/ParseIngredients200ResponseInnerNutritionPropertiesInner.md)
 - [ParseIngredients200ResponseInnerNutritionWeightPerServing](docs/ParseIngredients200ResponseInnerNutritionWeightPerServing.md)
 - [QuickAnswer200Response](docs/QuickAnswer200Response.md)
 - [SearchAllFood200Response](docs/SearchAllFood200Response.md)
 - [SearchAllFood200ResponseSearchResultsInner](docs/SearchAllFood200ResponseSearchResultsInner.md)
 - [SearchAllFood200ResponseSearchResultsInnerResultsInner](docs/SearchAllFood200ResponseSearchResultsInnerResultsInner.md)
 - [SearchCustomFoods200Response](docs/SearchCustomFoods200Response.md)
 - [SearchCustomFoods200ResponseCustomFoodsInner](docs/SearchCustomFoods200ResponseCustomFoodsInner.md)
 - [SearchFoodVideos200Response](docs/SearchFoodVideos200Response.md)
 - [SearchFoodVideos200ResponseVideosInner](docs/SearchFoodVideos200ResponseVideosInner.md)
 - [SearchGroceryProducts200Response](docs/SearchGroceryProducts200Response.md)
 - [SearchGroceryProductsByUpc200Response](docs/SearchGroceryProductsByUpc200Response.md)
 - [SearchGroceryProductsByUpc200ResponseIngredientsInner](docs/SearchGroceryProductsByUpc200ResponseIngredientsInner.md)
 - [SearchGroceryProductsByUpc200ResponseNutrition](docs/SearchGroceryProductsByUpc200ResponseNutrition.md)
 - [SearchGroceryProductsByUpc200ResponseServings](docs/SearchGroceryProductsByUpc200ResponseServings.md)
 - [SearchMenuItems200Response](docs/SearchMenuItems200Response.md)
 - [SearchMenuItems200ResponseMenuItemsInner](docs/SearchMenuItems200ResponseMenuItemsInner.md)
 - [SearchRecipes200Response](docs/SearchRecipes200Response.md)
 - [SearchRecipes200ResponseResultsInner](docs/SearchRecipes200ResponseResultsInner.md)
 - [SearchRecipesByIngredients200ResponseInner](docs/SearchRecipesByIngredients200ResponseInner.md)
 - [SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner](docs/SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner.md)
 - [SearchRecipesByNutrients200ResponseInner](docs/SearchRecipesByNutrients200ResponseInner.md)
 - [SearchRestaurants200Response](docs/SearchRestaurants200Response.md)
 - [SearchRestaurants200ResponseRestaurantsInner](docs/SearchRestaurants200ResponseRestaurantsInner.md)
 - [SearchRestaurants200ResponseRestaurantsInnerAddress](docs/SearchRestaurants200ResponseRestaurantsInnerAddress.md)
 - [SearchRestaurants200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHours.md)
 - [SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [SearchSiteContent200Response](docs/SearchSiteContent200Response.md)
 - [SearchSiteContent200ResponseArticlesInner](docs/SearchSiteContent200ResponseArticlesInner.md)
 - [SearchSiteContent200ResponseGroceryProductsInner](docs/SearchSiteContent200ResponseGroceryProductsInner.md)
 - [SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner](docs/SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner.md)
 - [SummarizeRecipe200Response](docs/SummarizeRecipe200Response.md)
 - [TalkToChatbot200Response](docs/TalkToChatbot200Response.md)


To get access to the crate's generated documentation, use:

```
cargo doc --open
```

## Author

mail@spoonacular.com

